@@ -6,17 +6,13 @@
 # nocov
 
 make_bag_mars <- function() {
-  parsnip::set_new_model("bag_mars")
-
-  parsnip::set_model_mode("bag_mars", "classification")
-  parsnip::set_model_mode("bag_mars", "regression")
-
-  # ----------------------------------------------------------------------------
 
   parsnip::set_model_engine("bag_mars", "classification", "earth")
   parsnip::set_model_engine("bag_mars", "regression", "earth")
-  parsnip::set_dependency("bag_mars", "earth", "earth")
-  parsnip::set_dependency("bag_mars", "earth", "baguette")
+  parsnip::set_dependency("bag_mars", "earth", "earth", mode = "classification")
+  parsnip::set_dependency("bag_mars", "earth", "earth", mode = "regression")
+  parsnip::set_dependency("bag_mars", "earth", "baguette", mode = "classification")
+  parsnip::set_dependency("bag_mars", "earth", "baguette", mode = "regression")
 
   parsnip::set_model_arg(
     model = "bag_mars",
