@@ -6,17 +6,13 @@
 # nocov
 
 make_bag_tree <- function() {
-  parsnip::set_new_model("bag_tree")
-
-  parsnip::set_model_mode("bag_tree", "classification")
-  parsnip::set_model_mode("bag_tree", "regression")
-
-  # ----------------------------------------------------------------------------
 
   parsnip::set_model_engine("bag_tree", "classification", "rpart")
   parsnip::set_model_engine("bag_tree", "regression", "rpart")
-  parsnip::set_dependency("bag_tree", "rpart", "rpart")
-  parsnip::set_dependency("bag_tree", "rpart", "baguette")
+  parsnip::set_dependency("bag_tree", "rpart", "rpart", mode = "classification")
+  parsnip::set_dependency("bag_tree", "rpart", "rpart", mode = "regression")
+  parsnip::set_dependency("bag_tree", "rpart", "baguette", mode = "classification")
+  parsnip::set_dependency("bag_tree", "rpart", "baguette", mode = "regression")
 
   parsnip::set_model_arg(
     model = "bag_tree",
@@ -148,8 +144,8 @@ make_bag_tree <- function() {
   # ------------------------------------------------------------------------------
 
   parsnip::set_model_engine("bag_tree", "classification", "C5.0")
-  parsnip::set_dependency("bag_tree", "C5.0", "C50")
-  parsnip::set_dependency("bag_tree", "C5.0", "baguette")
+  parsnip::set_dependency("bag_tree", "C5.0", "C50", mode = "classification")
+  parsnip::set_dependency("bag_tree", "C5.0", "baguette", mode = "classification")
 
   parsnip::set_fit(
     model = "bag_tree",
